/* ssl_null.c */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
 * All rights reserved.
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * See the COPYRIGHT file in the SSLeay distribution for more details.
 */

#include <stdio.h>
#include "ssl_locl.h"
#include "ssl_null.h"

int ssl_enc_null_init(s, client)
SSL *s;
int client;
	{
	NULL_STATE *ns;

	if (s->crypt_state == NULL)
		s->crypt_state=(char *)malloc(sizeof(NULL_STATE));
	if (s->crypt_state == NULL)
		goto err;
	ns=(NULL_STATE *)s->crypt_state;
	
	if (client)
		{
		s->read_key= &(ns->a[0]);
		s->write_key= &(ns->b[0]);
		}
	else
		{
		s->read_key= &(ns->b[0]);
		s->write_key= &(ns->a[0]);
		}
	memcpy(&(ns->a[0]),s->conn->master_key,8);
	memcpy(&(ns->b[0]),s->conn->master_key,8);
	return(1);
err:
	SSL_errno=SSL_ERRCODE(SSL_F_SSL_ENC_NULL_INIT,SSL_R_OUT_OF_MEMORY);
	return(0);
	}

/* read from s->mac_data and writes to s->mac_data s->length bytes */
void ssl_enc_null(s)
SSL *s;
	{
/*	int i;
	unsigned char *k,*p;

	if (s->send)
		k=s->write_key;
	else
		k=s->read_key;

	p=s->mac_data;
	for (i=0; i<s->length; i++)
		*(p++)^=k[i%8];
*/	}

void ssl_compute_null_mac(s, md)
SSL *s;
char *md;
	{
	return;
	}
